summaryrefslogtreecommitdiffstats
path: root/src/occ_405/amec/amec_slave_smh.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/occ_405/amec/amec_slave_smh.c')
-rwxr-xr-xsrc/occ_405/amec/amec_slave_smh.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/occ_405/amec/amec_slave_smh.c b/src/occ_405/amec/amec_slave_smh.c
index 5293f2f..e30dd5c 100755
--- a/src/occ_405/amec/amec_slave_smh.c
+++ b/src/occ_405/amec/amec_slave_smh.c
@@ -1366,10 +1366,11 @@ void amec_slv_substate_7_0(void)
// Call memory thermal controller based on DIMM temperature
amec_controller_dimm_thermal();
- if (MEM_TYPE_CUMULUS == G_sysConfigData.mem_type)
+ if ((MEM_TYPE_CUMULUS == G_sysConfigData.mem_type) ||
+ (MEM_TYPE_OCM == G_sysConfigData.mem_type))
{
- // Call memory thermal controller based on Centaur temperature
- amec_controller_centaur_thermal();
+ // Call memory thermal controller based on membuf temperature
+ amec_controller_membuf_thermal();
}
}
OpenPOWER on IntegriCloud